@@ -13,7 +13,7 @@ use Test::BDD::Cucumber::StepFile qw();
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our @EXPORT_OK = qw(S C request_send code_eq header_re header_set content_re content_set);
 our %EXPORT_TAGS = ( util => [qw(request_send code_eq header_re header_set content_re content_set)] );
@@ -90,6 +90,10 @@ my $validator_request_send = validation_for(
 sub request_send {
     my ( $method, $url ) = $validator_request_send->(@_);
 
+    if ( $ENV{BDD_HTTP_HOST} ) {
+        $url =~ s/\$BDD_HTTP_HOST/$ENV{BDD_HTTP_HOST}/x;
+    }
+
     my $options = {
         headers => S->{http}->{request}->{headers},
         content => S->{http}->{request}->{content},
